==> tine20-allinone_2020.08.8.tar.bz2: Addressbook/js/Addressbook-lang-zh_TW-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (Taiwan) (http://www.transifex.com/tine20/tine20/language/zh_TW/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: zh_TW\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "公司聯絡資料"

, "Organisation / Unit"
: "單位 / 組織"

, "Business Address"
: "公司地址"

, "Email"
: "公司電子郵件"

, "Telephone Work"
: "公司電話"

, "Telephone Cellphone"
: "手機號碼"

, "Telephone Car"
: "車用電話"

, "Telephone Fax"
: "傳真電話"

, "Telephone Page"
: "Telephone Page"

, "URL"
: "網址"

, "Role"
: "角色"

, "Room"
: "房號"

, "Assistant"
: "助理"

, "Assistant Telephone"
: "助理電話"

, "Private Contact Data"
: "個人聯絡資料"

, "Private Address"
: "個人地址"

, "Email Home"
: "私人電子郵件"

, "Telephone Home"
: "私人電話"

, "Telephone Cellphone Private"
: "私人手機號碼"

, "Telephone Fax Home"
: "私人傳真號碼"

, "URL Home"
: "個人網址"

, "Other Data"
: "其他資料"

, "Birthday"
: "生日"

, "Job Title"
: "職稱"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  ""

]
, "Percent"
: ""

, "Description"
: "說明"

, "Members"
: ""

, "Type"
: ""

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  ""

]
, "Contact, Contacts"
: [
  "聯絡人"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "國別"

, "City"
: "縣市"

, "Postalcode"
: "郵遞區號"

, "Region"
: ""

, "Street"
: "街"

, "Street 2"
: "街道2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "國別 (個人)"

, "City (private)"
: "縣市 (個人)"

, "Postalcode (private)"
: "郵遞區號 (個人)"

, "Region (private)"
: ""

, "Street (private)"
: "街 (個人)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "電子郵件 (個人)"

, "Free/Busy URI"
: ""

, "Geo"
: ""

, "Groups"
: ""

, "Industry, Industries"
: [
  ""

]
, "Note"
: "備註"

, "Last Name"
: "姓氏"

, "Display Name"
: "顯示名稱"

, "Full Name"
: "全名"

, "First Name"
: "姓名"

, "Middle Name"
: ""

, "Title"
: "職稱"

, "Suffix"
: ""

, "Company"
: "公司名稱"

, "Unit"
: ""

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: ""

, "Salutation"
: ""

, "syncBackendIds"
: ""

, "Car phone"
: "車用電話"

, "Mobile"
: "手機號碼"

, "Mobile (private)"
: "手機號碼 (個人)"

, "Fax"
: "傳真號碼"

, "Fax (private)"
: "傳真號碼 (個人)"

, "Phone (private)"
: "電話 (個人)"

, "Pager"
: "呼叫器"

, "Phone"
: "電話"

, "Timezone"
: "時區"

, "Web"
: "網址"

, "URL (private)"
: "網址 (個人)"

, "Label"
: ""

, "Lists"
: ""

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "聯絡資料"

, "Company Address"
: "公司地址"

, "New Contact"
: ""

, "ID"
: ""

, "Name"
: ""

, "Structure, Structures"
: [
  ""

]
, "Resources"
: ""

, "Import contacts"
: ""

, "Contact of a user account"
: ""

, "No name"
: ""

, "Business"
: ""

, "Private"
: ""

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: ""

, "List Roles"
: ""

, "Street (Company Address)"
: ""

, "Street 2 (Company Address)"
: ""

, "City (Company Address)"
: ""

, "Region (Company Address)"
: ""

, "Postal Code (Company Address)"
: ""

, "Country (Company Address)"
: ""

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: ""

, "Street 2 (Private Address)"
: ""

, "City (Private Address)"
: ""

, "Region (Private Address)"
: ""

, "Postal Code (Private Address)"
: ""

, "Country (Private Address)"
: ""

, "Company Communication"
: ""

, "Private Communication"
: ""

, "E-Mail"
: "電子郵件"

, "E-Mail (private)"
: "電子郵件 (個人)"

, "Web (private)"
: ""

, "Contacts"
: "聯絡人"

, "Addressbooks"
: ""

, "User Account"
: ""

, "Quick Search"
: ""

, "Postal Code"
: "郵遞區號"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Email Address, Email Addresses"
: [
  ""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "輸入說明"

, "{0} must be given"
: ""

, "Member of List"
: ""

, "Map"
: ""

, "Company address"
: ""

, "Private address"
: ""

, "CardDAV URL"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "個人資料"

, "Parse address"
: ""

, "Print contact"
: ""

, "Paste address"
: ""

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: ""

, "Remove Member"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "All contacts"
: ""

, "Default Addressbook"
: ""

, "The default addressbook for new contacts"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on addressbook startup"
: ""

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: ""

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: ""

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: ""

, "Mr"
: "先生"

, "Ms"
: "小姐"

, "Parsing rules for addresses"
: ""

, "Path to a XML file with address parsing rules."
: ""

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: ""

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: ""

, "Contact CSV import from mac address book"
: ""

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: ""

, "manage shared addressbooks"
: ""

, "Create new shared addressbook folders"
: ""

, "manage shared addressbook favorites"
: ""

, "Create or update shared addressbook favorites"
: ""

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""

]
, "%s's personal addressbook"
: "%s 的個人通訊錄"

, "All contacts I have read grants for"
: ""

, "My company"
: ""

, "All coworkers in my company"
: ""

, "My contacts"
: ""

, "All contacts in my Addressbooks"
: ""

, "Last modified by me"
: ""

, "All contacts that I have last modified"
: ""

, "Internal Contacts"
: "分機號碼"

, "List"
: ""

, "Addressbook"
: ""

, "Contact"
: "聯絡人"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Addressbook/js/Addressbook-lang-zh_TW-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:45+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (Taiwan) (http://www.transifex.com/tine20/tine20/language/zh_TW/)\nLanguage: zh_TW\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Map"
: ""

, "Preferred Address"
: ""

, "Personal Information"
: "個人資料"

, "Salutation"
: ""

, "Title"
: "職稱"

, "Short Name"
: ""

, "First Name"
: "姓名"

, "Middle Name"
: ""

, "Last Name"
: "姓氏"

, "Company"
: "公司名稱"

, "Unit"
: ""

, "Display Name"
: "顯示名稱"

, "Industry, Industries"
: [
  ""

]
, "Job Title"
: "職稱"

, "Birthday (private)"
: ""

, "Contact Information"
: "聯絡資料"

, "Phone"
: "電話"

, "Mobile"
: "手機號碼"

, "Fax"
: "傳真號碼"

, "Phone (private)"
: "電話 (個人)"

, "Mobile (private)"
: "手機號碼 (個人)"

, "Fax (private)"
: "傳真號碼 (個人)"

, "E-Mail"
: "電子郵件"

, "E-Mail (private)"
: "電子郵件 (個人)"

, "Web"
: "網址"

, "Company Address"
: "公司地址"

, "Street"
: "街"

, "Street 2"
: "街道2"

, "Region"
: ""

, "Postal Code"
: "郵遞區號"

, "City"
: "縣市"

, "Country"
: "國別"

, "Private Address"
: "個人地址"

, "Description"
: "說明"

, "Enter description"
: "輸入說明"

, "Groups"
: ""

, "Parse address"
: ""

, "Print contact"
: ""

, "Paste address"
: ""

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Mailing List"
: ""

, "This group is a mailing list"
: ""

, "Keep copy of group mails"
: ""

, "Forward external mails"
: ""

, "Only forward member mails"
: ""

, "Only forward to system email accounts"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Contact, Contacts"
: [
  "聯絡人"

]
, "Members"
: ""

, "Search for members ..."
: ""

, "List Roles"
: ""

, "Remove Member"
: ""

, "CardDAV URL"
: ""

, "New Contact"
: ""

, "Addressbook, Addressbooks"
: [
  ""

]
, "ID"
: ""

, "Name"
: ""

, "Structure, Structures"
: [
  ""

]
, "Resources"
: ""

, "Private"
: ""

, "The grant to access contacts private information"
: ""

, "Contact Personal Grant, Contact Personal Grants"
: [
  ""

]
, "List Personal Grant, List Personal Grants"
: [
  ""

]
, "List Information"
: ""

, "List type"
: ""

, "System accounts only"
: ""

, "{0} must be given"
: ""

, "List Functions"
: ""

, "Suffix"
: ""

, "Birthday"
: "生日"

, "Job Role"
: ""

, "Room"
: "房號"

, "Street (Company Address)"
: ""

, "Street 2 (Company Address)"
: ""

, "City (Company Address)"
: ""

, "Region (Company Address)"
: ""

, "Postal Code (Company Address)"
: ""

, "Country (Company Address)"
: ""

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: ""

, "Street 2 (Private Address)"
: ""

, "City (Private Address)"
: ""

, "Region (Private Address)"
: ""

, "Postal Code (Private Address)"
: ""

, "Country (Private Address)"
: ""

, "Company Communication"
: ""

, "Private Communication"
: ""

, "Web (private)"
: ""

, "Contacts"
: "聯絡人"

, "Addressbooks"
: ""

, "User Account"
: ""

, "Quick Search"
: ""

, "Type"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "List, Lists"
: [
  ""

]
, "Lists"
: ""

, "Email Address, Email Addresses"
: [
  ""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""

]
, "GENDER_List Function"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "Business"
: ""

, "Import contacts"
: ""

, "Contact of a user account"
: ""

, "No name"
: ""

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: ""

, "Full Name"
: "全名"

, "Postalcode"
: "郵遞區號"

, "Street (private)"
: "街 (個人)"

, "City (private)"
: "縣市 (個人)"

, "Region (private)"
: ""

, "Postalcode (private)"
: "郵遞區號 (個人)"

, "Country (private)"
: "國別 (個人)"

, "Email"
: "公司電子郵件"

, "Car phone"
: "車用電話"

, "Pager"
: "呼叫器"

, "Email (private)"
: "電子郵件 (個人)"

, "URL (private)"
: "網址 (個人)"

, "Note"
: "備註"

, "Timezone"
: "時區"

, "Geo"
: ""

, "Select list"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Company address"
: ""

, "Private address"
: ""

, "Member E-Mails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "All contacts"
: ""

, "Default Addressbook"
: ""

, "The default addressbook for new contacts"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on addressbook startup"
: ""

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Mailinglists"
: ""

, "Make group and lists to mailinglists"
: ""

, "Addressbook Short Names"
: ""

, "Add Short Name field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact (id) representing this installation"
: ""

, "Contact duplicate check fields"
: ""

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: ""

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: ""

, "Mr"
: "先生"

, "Ms"
: "小姐"

, "Parsing rules for addresses"
: ""

, "Path to a XML file with address parsing rules."
: ""

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Site Filter"
: ""

, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
: ""

, "Sync Backends"
: ""

, "Default telephone country code"
: ""

, "%s's personal addressbook"
: "%s 的個人通訊錄"

, "Business Contact Data"
: "公司聯絡資料"

, "Organisation / Unit"
: "單位 / 組織"

, "Business Address"
: "公司地址"

, "Telephone Work"
: "公司電話"

, "Telephone Cellphone"
: "手機號碼"

, "Telephone Car"
: "車用電話"

, "Telephone Fax"
: "傳真電話"

, "Telephone Page"
: "Telephone Page"

, "URL"
: "網址"

, "Role"
: "角色"

, "Assistant"
: "助理"

, "Assistant Telephone"
: "助理電話"

, "Private Contact Data"
: "個人聯絡資料"

, "Email Home"
: "私人電子郵件"

, "Telephone Home"
: "私人電話"

, "Telephone Cellphone Private"
: "私人手機號碼"

, "Telephone Fax Home"
: "私人傳真號碼"

, "URL Home"
: "個人網址"

, "Other Data"
: "其他資料"

, "OpenDocument all data"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "Word letter"
: ""

, "PDF details"
: ""

, "Excel all data"
: ""

, "VCard Report"
: ""

, "Export multiple addressbooks to vcf files"
: ""

, "Relations"
: ""

, "CSV all data"
: ""

, "VCard/VCF"
: ""

, "Export contact data into vcf file"
: ""

, "Addressbooks to export"
: ""

, "Export target"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: ""

, "Contact CSV import from mac address book"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: ""

, "Import CSV formated contacts from Outlook 2010 German address book"
: ""

, "CSV Outlook 2010 German"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: ""

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: ""

, "GENDER_List"
: ""

, "Name/Email"
: ""

, "GENDER_Contact"
: ""

, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Longitude"
: ""

, "Latitude"
: ""

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Free/Busy URI"
: ""

, "Paths"
: ""

, "syncBackendIds"
: ""

, "Label"
: ""

, "It is not allowed to add non-account contacts to this list"
: ""

, "E-Mail address is already given. Please choose another one."
: ""

, "It is not allowed to delete a contact linked to an user account!"
: ""

, "This Short Name already exists. How about {0}?"
: ""

, "Internal Contacts"
: "分機號碼"

, "All contacts I have read grants for"
: ""

, "My company"
: ""

, "All coworkers in my company"
: ""

, "My contacts"
: ""

, "All contacts in my Addressbooks"
: ""

, "Last modified by me"
: ""

, "All contacts that I have last modified"
: ""

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "manage shared addressbooks"
: ""

, "Create new shared addressbook folders"
: ""

, "manage shared addressbook favorites"
: ""

, "Create or update shared addressbook favorites"
: ""

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Manage list email options"
: ""

, "Manage list email options like mailing lists"
: ""

, "Account"
: ""

, "Exporttime"
: ""

, "28"
: ""

, "20"
: ""

, "00877546"
: ""

, "en-GB"
: ""

, "00813B4E"
: ""

, "Gruppenrollen"
: ""

, "00DA3FCD"
: ""

, "00997199"
: ""

, "0009326B"
: ""

, "008C27A5"
: ""

, "00C96397"
: ""

, "00046462"
: ""

, "Relation, Relations"
: [
  ""

]
, "Industry"
: ""

, "Contact"
: "聯絡人"

, "Addressbook"
: ""

, "Structure"
: ""

, "Contact Personal Grant"
: ""

, "List Personal Grant"
: ""

, "List"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
